pub struct LocalActionCache { /* private fields */ }Expand description
A local index from action digests to their referenced cache objects.
Implementations
Sourceimpl LocalActionCache
impl LocalActionCache
Sourcepub fn path_for(&self, action: &CacheDigest) -> Result<PathBuf>
pub fn path_for(&self, action: &CacheDigest) -> Result<PathBuf>
Resolve the storage path for an action digest.
Sourcepub fn find(&self, action: &CacheDigest) -> Result<Option<RemoteActionResult>>
pub fn find(&self, action: &CacheDigest) -> Result<Option<RemoteActionResult>>
Find and strictly validate a canonical action result.
Sourcepub fn store(&self, result: &RemoteActionResult) -> Result<PathBuf>
pub fn store(&self, result: &RemoteActionResult) -> Result<PathBuf>
Atomically publish an action result after validating all referenced objects.